@@ -16,10 +16,16 @@ __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_FeatherWing.git"
 
 import board
-import adafruit_ht16k33.matrix as matrix
+from adafruit_ht16k33 import matrix
 
 from adafruit_featherwing.auto_writeable import AutoWriteable
 
+try:
+    from typing import Optional, Tuple, Union
+    from busio import I2C
+except ImportError:
+    pass
+
 
 class MatrixFeatherWing(AutoWriteable):
     """Class representing an `Adafruit 8x16 LED Matrix FeatherWing
@@ -27,7 +33,7 @@ class MatrixFeatherWing(AutoWriteable):
 
     Automatically uses the feather's I2C bus."""
 
-    def __init__(self, address=0x70, i2c=None):
+    def __init__(self, address: int = 0x70, i2c: Optional[I2C] = None):
 
         if i2c is None:
             i2c = board.I2C()
@@ -37,14 +43,14 @@ class MatrixFeatherWing(AutoWriteable):
         self.rows = 8
         super().__init__()
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: Tuple[int, int]) -> bool:
         """
         Get the current value of a pixel
         """
         x, y = key
         return self.pixel(x, y)
 
-    def __setitem__(self, key, value):
+    def __setitem__(self, key: Tuple[int, int], value: Union[int, bool]):
         """
         Turn a pixel off or on
         """
@@ -59,7 +65,7 @@ class MatrixFeatherWing(AutoWriteable):
         if self._auto_write:
             self._matrix.show()
 
-    def pixel(self, x, y, color=None):
+    def pixel(self, x: int, y: int, color: Optional[bool] = None) -> Optional[bool]:
         """
         Turn a pixel on or off or retrieve a pixel value
 
@@ -79,7 +85,7 @@ class MatrixFeatherWing(AutoWriteable):
         """
         self._matrix.show()
 
-    def fill(self, fill):
+    def fill(self, fill: bool):
         """
         Turn all pixels on or off
 
@@ -92,7 +98,7 @@ class MatrixFeatherWing(AutoWriteable):
         else:
             raise ValueError("Must set to either True or False.")
 
-    def shift_right(self, rotate=False):
+    def shift_right(self, rotate: bool = False):
         """
         Shift all pixels right
 
@@ -101,7 +107,7 @@ class MatrixFeatherWing(AutoWriteable):
         self._matrix.shift_right(rotate)
         self._update()
 
-    def shift_left(self, rotate=False):
+    def shift_left(self, rotate: bool = False):
         """
         Shift all pixels left
 
@@ -110,7 +116,7 @@ class MatrixFeatherWing(AutoWriteable):
         self._matrix.shift_left(rotate)
         self._update()
 
-    def shift_up(self, rotate=False):
+    def shift_up(self, rotate: bool = False):
         """
         Shift all pixels up
 
@@ -119,7 +125,7 @@ class MatrixFeatherWing(AutoWriteable):
         self._matrix.shift_up(rotate)
         self._update()
 
-    def shift_down(self, rotate=False):
+    def shift_down(self, rotate: bool = False):
         """
         Shift all pixels down
 
@@ -138,7 +144,7 @@ class MatrixFeatherWing(AutoWriteable):
         return self._matrix.blink_rate
 
     @blink_rate.setter
-    def blink_rate(self, rate):
+    def blink_rate(self, rate: int):
         self._matrix.blink_rate = rate
 
     @property
@@ -150,7 +156,7 @@ class MatrixFeatherWing(AutoWriteable):
         return round(self._matrix.brightness * 15)
 
     @brightness.setter
-    def brightness(self, brightness):
+    def brightness(self, brightness: int):
         if not 0 <= brightness <= 15:
             raise ValueError("Brightness must be a value between 0 and 15")
         self._matrix.brightness = brightness / 15
