@@ -23,6 +23,14 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_FeatherWing.git"
 from adafruit_hx8357 import HX8357
 from adafruit_featherwing.tft_featherwing import TFTFeatherWing
 
+try:
+    from typing import Optional
+    from busio import SPI
+    from microcontroller import Pin
+except ImportError:
+    pass
+
+
 # pylint: disable-msg=too-few-public-methods, too-many-arguments
 class TFTFeatherWing35(TFTFeatherWing):
     """Class representing an `TFT FeatherWing 3.5
@@ -30,6 +38,13 @@ class TFTFeatherWing35(TFTFeatherWing):
 
     """
 
-    def __init__(self, spi=None, cs=None, dc=None, ts_cs=None, sd_cs=None):
+    def __init__(
+        self,
+        spi: Optional[SPI] = None,
+        cs: Optional[Pin] = None,
+        dc: Optional[Pin] = None,
+        ts_cs: Optional[Pin] = None,
+        sd_cs: Optional[Pin] = None,
+    ):
         super().__init__(spi, cs, dc, ts_cs, sd_cs)
         self.display = HX8357(self._display_bus, width=480, height=320)
