@@ -13,13 +13,12 @@ from adafruit_featherwing import tft_featherwing_24
 tft_featherwing = tft_featherwing_24.TFTFeatherWing24()
 
 try:
-    f = open("/sd/tft_featherwing.txt", "w")
-    f.write("Blinka\nBlackberry Q10 Keyboard")
-    f.close()
+    with open("/sd/tft_featherwing.txt", "w") as f:
+        f.write("Blinka\nBlackberry Q10 Keyboard")
+
+    with open("/sd/tft_featherwing.txt", "r") as f:
+        print(f.read())
 
-    f = open("/sd/tft_featherwing.txt", "r")
-    print(f.read())
-    f.close()
 except OSError as error:
     print("Unable to write to SD Card.")
 
